@@ -1,14 +1,13 @@
 mod utils;
 
-use utils::logging; 
 use fers_calculations::models::fers::fers::FERS;
+use log::debug;
+use log::error;
 use std::fs;
 use std::io::Write;
-use utoipa::OpenApi;
-use log::debug;
-use log::error;           
 use std::process;
-
+use utils::logging;
+use utoipa::OpenApi;
 
 #[derive(OpenApi)]
 #[openapi(
@@ -18,7 +17,7 @@ use std::process;
         title = "FERS Structural Analysis API",
         version = "0.1.0",
         description = "OpenAPI for FERS structural analysis application."
-    ),
+    )
 )]
 struct ApiDoc;
 
@@ -33,10 +32,12 @@ fn main() {
     }
 
     // Read and parse JSON input file
-    let file_content = fs::read_to_string("014_Simply_Supported_with_Uniform_Distributed_Load.json").expect("Failed to read the JSON file");
+    let file_content =
+        fs::read_to_string("051_Member_hinge_at_half.json").expect("Failed to read the JSON file");
     // let file_content = fs::read_to_string("001_cantilever_with_end_load.json").expect("Failed to read the JSON file");
     // let file_content = fs::read_to_string("004_triangular.json").expect("Failed to read the JSON file");
-    let mut fers_data: FERS = serde_json::from_str(&file_content).expect("JSON was not well-formatted");
+    let mut fers_data: FERS =
+        serde_json::from_str(&file_content).expect("JSON was not well-formatted");
 
     let member_count = fers_data.get_member_count();
     if member_count > 100 {
@@ -67,10 +68,12 @@ fn main() {
                 } else {
                     debug!("Internal results written to 'internal_results.json'");
                 }
-
             }
             Err(e) => {
-                debug!("Error during analysis for Load Case {}: {}", first_load_case_id, e);
+                debug!(
+                    "Error during analysis for Load Case {}: {}",
+                    first_load_case_id, e
+                );
             }
         }
     } else {
