@@ -59,12 +59,6 @@ pub struct AssemblyContext<'a> {
     pub support_by_id: HashMap<u32, &'a NodalSupport>,
 }
 
-pub struct Vec3 {
-    x: f64,
-    y: f64,
-    z: f64,
-}
-
 impl<'a> AssemblyContext<'a> {
     pub fn new(model: &'a FERS) -> Self {
         let (material_by_id, section_by_id, hinge_by_id, support_by_id) = model.build_lookup_maps();
@@ -227,8 +221,6 @@ impl FERS {
         displacement_vector_full: &nalgebra::DMatrix<f64>,
         external_load_vector_full: &nalgebra::DMatrix<f64>,
     ) -> Result<nalgebra::DMatrix<f64>, String> {
-        // Operator without geometric part
-        let linear_operator_full = self.build_operator_with_supports(active_member_map, None)?;
         let residual_vector_full = self.compute_full_residual_with_rigid_constraints(
             active_member_map,
             displacement_vector_full,
@@ -239,16 +231,6 @@ impl FERS {
         let spring_reaction_vector_full =
             self.compute_support_spring_reaction_vector_verbose(displacement_vector_full)?;
 
-        // (Optional) keep your debug blocks; consider gating them behind a feature flag.
-        for node_id in 1..=3 {
-            let base_index = (node_id - 1) * 6;
-            let mut row_abs_sums = [0.0; 6];
-            for local_dof in 0..6 {
-                let row = linear_operator_full.row(base_index + local_dof);
-                row_abs_sums[local_dof] = row.iter().map(|value| value.abs()).sum::<f64>();
-            }
-            log::debug!("K row-abs-sums @ node {} = {:?}", node_id, row_abs_sums);
-        }
         let base_index_node1 = (1usize - 1) * 6;
         log::debug!(
             "node 1 residual Fx..Mz = {:?}",
@@ -548,10 +530,6 @@ impl FERS {
                 let row_b = FERS::dof_index(info.b, i);
 
                 // Zero the row_b to avoid accidental accumulation if multiple edges ever touched it
-                for col in 0..n_red {
-                    // keep it zero while we add contributions below
-                    // (if the DOF is also retained, it would not be in 'eliminated' set)
-                }
 
                 // S[row_b, :] = Σ_j C[i,j] * S[row_a_j, :]
                 for j in 0..6 {
@@ -1268,13 +1246,15 @@ impl FERS {
         displacement_vector: &DMatrix<f64>,
         global_reaction_vector: &DMatrix<f64>,
     ) -> Result<&Results, String> {
-        // Build the three main maps
+        use std::cmp::Reverse;
+
+        // 1) Element/member results + basic node maps
         let member_results =
             compute_member_results_from_displacement(self, &result_type, displacement_vector);
         let displacement_nodes = extract_displacements(self, displacement_vector);
         let mut reaction_nodes = extract_reaction_nodes(self, global_reaction_vector);
 
-        // ---- Build: member_id -> (start_node_id, end_node_id)
+        // ---- member_id -> (start_node_id, end_node_id)
         let mut member_ends: HashMap<u32, (u32, u32)> = HashMap::new();
         for ms in &self.member_sets {
             for m in &ms.members {
@@ -1282,14 +1262,14 @@ impl FERS {
             }
         }
 
-        // ---- Accumulate nodal forces from member end forces
+        // 2) Net nodal forces coming from **deformable** members only
+
         let mut node_force: HashMap<u32, (f64, f64, f64)> = HashMap::new();
         for (mid, mr) in &member_results {
             let Some(&(n_start, n_end)) = member_ends.get(mid) else {
                 continue;
             };
 
-            // add start-end forces to their respective nodes
             let e = node_force.entry(n_start).or_insert((0.0, 0.0, 0.0));
             e.0 += mr.start_node_forces.fx;
             e.1 += mr.start_node_forces.fy;
@@ -1301,38 +1281,62 @@ impl FERS {
             e.2 += mr.end_node_forces.fz;
         }
 
-        // ---- Rigid-arm correction: for each rigid member a->b, add (r × F_b) at master 'a'
+        // 3) Build rigid-link parent map: slave -> (master, r = x_b - x_a)
+        let mut parent: HashMap<u32, (u32, (f64, f64, f64))> = HashMap::new();
+        let mut rigid_edges: Vec<(u32, u32, (f64, f64, f64))> = Vec::new(); // (a, b, r_ab)
         for ms in &self.member_sets {
             for m in &ms.members {
                 if !matches!(m.member_type, MemberType::Rigid) {
                     continue;
                 }
-
-                let a = m.start_node.id; // master
-                let b = m.end_node.id; // slave
-
-                // r = x_b - x_a
-                let rx = m.end_node.X - m.start_node.X;
-                let ry = m.end_node.Y - m.start_node.Y;
-                let rz = m.end_node.Z - m.start_node.Z;
-
-                let (fx_b, fy_b, fz_b) = node_force.get(&b).copied().unwrap_or((0.0, 0.0, 0.0));
-
-                // r × F_b
-                let mx = ry * fz_b - rz * fy_b;
-                let my = rz * fx_b - rx * fz_b;
-                let mz = rx * fy_b - ry * fx_b;
-
-                if let Some(rnode) = reaction_nodes.get_mut(&a) {
-                    rnode.nodal_forces.mx += mx;
-                    rnode.nodal_forces.my += my;
-                    rnode.nodal_forces.mz += mz;
-                }
+                let a = m.start_node.id;
+                let b = m.end_node.id;
+                let r = (
+                    m.end_node.X - m.start_node.X,
+                    m.end_node.Y - m.start_node.Y,
+                    m.end_node.Z - m.start_node.Z,
+                );
+                parent.insert(b, (a, r));
+                rigid_edges.push((a, b, r));
             }
         }
-        // ---- end correction
 
-        // Summaries
+        fn depth_of(node: u32, parent: &HashMap<u32, (u32, (f64, f64, f64))>) -> usize {
+            let mut d = 0usize;
+            let mut p = node;
+            while let Some(&(pp, _)) = parent.get(&p) {
+                d += 1;
+                p = pp;
+            }
+            d
+        }
+
+        // 4) Rigid-arm correction:
+        rigid_edges.sort_by_key(|&(_a, b, _)| Reverse(depth_of(b, &parent)));
+
+        for (a, b, (rx, ry, rz)) in rigid_edges {
+            let (fx_b, fy_b, fz_b) = node_force.get(&b).copied().unwrap_or((0.0, 0.0, 0.0));
+            if fx_b == 0.0 && fy_b == 0.0 && fz_b == 0.0 {
+                continue;
+            }
+
+            let mx = ry * fz_b - rz * fy_b;
+            let my = rz * fx_b - rx * fz_b;
+            let mz = rx * fy_b - ry * fx_b;
+
+            if let Some(rnode) = reaction_nodes.get_mut(&a) {
+                rnode.nodal_forces.mx += mx;
+                rnode.nodal_forces.my += my;
+                rnode.nodal_forces.mz += mz;
+            } else {
+                let e = node_force.entry(a).or_insert((0.0, 0.0, 0.0));
+                e.0 += fx_b;
+                e.1 += fy_b;
+                e.2 += fz_b;
+            }
+        }
+
+        // 5) Pack results & store
         let total_members: usize = self.member_sets.iter().map(|set| set.members.len()).sum();
         let total_supports: usize = self.nodal_supports.len();
 
@@ -1349,12 +1353,13 @@ impl FERS {
             },
             unity_checks: None,
         };
-        // Insert into bundle
+
         let bundle = self.results.get_or_insert_with(|| ResultsBundle {
             loadcases: BTreeMap::new(),
             loadcombinations: BTreeMap::new(),
             unity_checks_overview: None,
         });
+
         match result_type {
             ResultType::Loadcase(_) => {
                 if bundle.loadcases.insert(name.clone(), results).is_some() {
